@@ -1,13 +1,11 @@
 #' @title File info API
 #' @noRd
-#'
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #'
 #' @description
 #' Set of functions for handling `file_info`.
 #'
 NULL
-
 #' @title Get `file_info` from a given tile.
 #' @noRd
 #' @param tile  A tile.
@@ -16,7 +14,6 @@ NULL
     fi <- tile[["file_info"]][[1]]
     fi
 }
-
 #' @title Set `file_info` into a given tile.
 #' @noRd
 #' @param tile  A tile.
@@ -27,7 +24,10 @@ NULL
     tile[["file_info"]] <- list(value)
     tile
 }
-
+#' @title Get the type of the cube from `file_info`
+#' @noRd
+#' @param fi   file_info
+#' @returns Data cube type (eo_cube or derived_cube)
 .fi_type <- function(fi) {
     if ("date" %in% names(fi)) {
         "eo_cube"
@@ -37,14 +37,28 @@ NULL
         stop("invalid file info")
     }
 }
-
+#' @title Switch between `file_info` types
+#' @noRd
+#' @param fi   file_info
+#' @returns Data cube type (eo_cube or derived_cube)
 .fi_switch <- function(fi, ...) {
-    switch(.fi_type(fi),
-           ...,
-           stop("invalid file_info type")
-    )
+    switch(.fi_type(fi), ...)
 }
-
+#' @title Create a file_info for a new eo_cube
+#' @noRd
+#' @param fid file_info id
+#' @param band band
+#' @param date date of the image
+#' @param ncols number of cols in the image
+#' @param nrows number of rows in the image
+#' @param xres  spatial resolution of X dimension
+#' @param yres spatial resolution of Y dimension
+#' @param xmin smallest X coordinate
+#' @param xmax largest X coordinate
+#' @param ymin smallest Y coordinate
+#' @param ymax largest Y coordinate
+#' @param path location of the data
+#' @returns  eo_cube tibble
 .fi_eo <- function(fid, band, date, ncols, nrows, xres, yres, xmin, xmax,
                    ymin, ymax, path) {
     # Create a new eo file_info
@@ -63,7 +77,12 @@ NULL
         path = path
     )
 }
-
+#' @title Create a new eo_cube file_info from existing files
+#' @noRd
+#' @param files image files to be included
+#' @param fid file_info ids
+#' @param bands bands
+#' @param date date of the images
 .fi_eo_from_files <- function(files, fid, bands, date) {
     .check_that(length(files) == length(bands))
     files <- .file_normalize(files)
@@ -83,7 +102,21 @@ NULL
         path = files
     )
 }
-
+#' @title Create a file_info for a new derived_cube
+#' @noRd
+#' @param band band
+#' @param start_date start date of the image
+#' @param end_date end date of the image
+#' @param ncols number of cols in the image
+#' @param nrows number of rows in the image
+#' @param xres  spatial resolution of X dimension
+#' @param yres spatial resolution of Y dimension
+#' @param xmin smallest X coordinate
+#' @param xmax largest X coordinate
+#' @param ymin smallest Y coordinate
+#' @param ymax largest Y coordinate
+#' @param path location of the data
+#' @returns  eo_cube tibble
 .fi_derived <- function(band, start_date, end_date, ncols, nrows, xres, yres,
                         xmin, xmax, ymin, ymax, path) {
     # Create a new derived file_info
@@ -102,7 +135,12 @@ NULL
         path = path
     )
 }
-
+#' @title Create a new derived_cube file_info from existing files
+#' @noRd
+#' @param file image file to be included
+#' @param band band
+#' @param start_date start date of the image
+#' @param end_date end date of the image
 .fi_derived_from_file <- function(file, band, start_date, end_date) {
     file <- .file_normalize(file)
     r_obj <- .raster_open_rast(file)
@@ -122,14 +160,25 @@ NULL
     )
 }
 
+#' @title Get file_info id
+#' @noRd
+#' @param fi   file_info
+#' @returns file_info id
 .fi_fid <- function(fi) {
     .as_chr(fi[["fid"]])
 }
-
+#' @title Get file_info cloud cover values
+#' @noRd
+#' @param fi   file_info
+#' @returns values of cloud cover
 .fi_cloud_cover <- function(fi) {
     .as_dbl(fi[["cloud_cover"]])
 }
-
+#' @title Filter file_info for a file_info ID
+#' @noRd
+#' @param fi   file_info
+#' @param fid  file_info ID
+#' @returns file_info for the selected fid
 .fi_filter_fid <- function(fi, fid) {
     .fi_switch(
         fi = fi,
@@ -143,11 +192,18 @@ NULL
         }
     )
 }
-
+#' @title Get file_info bands
+#' @noRd
+#' @param fi   file_info
+#' @returns band values
 .fi_bands <- function(fi) {
     .as_chr(fi[["band"]])
 }
-
+#' @title Rename tbands of a file_info
+#' @noRd
+#' @param fi   file_info
+#' @param rename  new band names
+#' @returns file_info with new band names
 .fi_rename_bands <- function(fi, rename) {
     .check_chr_within(
         .fi_bands(fi),
@@ -157,7 +213,11 @@ NULL
     fi[["band"]] <- unname(rename[.fi_bands(fi)])
     fi
 }
-
+#' @title Filter file_info for bands
+#' @noRd
+#' @param fi   file_info
+#' @param bands  selected bands
+#' @returns file_info filtered for the chosen bands
 .fi_filter_bands <- function(fi, bands) {
     bands_in_fi <- bands %in% .fi_bands(fi)
     if (!all(bands_in_fi)) {
@@ -166,7 +226,10 @@ NULL
     }
     fi[.fi_bands(fi) %in% bands, ]
 }
-
+#' @title Get file_info minimum date
+#' @noRd
+#' @param fi   file_info
+#' @returns first date
 .fi_min_date <- function(fi) {
     .fi_switch(
         fi = fi,
@@ -174,7 +237,10 @@ NULL
         derived_cube = min(.as_date(fi[["start_date"]]))
     )
 }
-
+#' @title Get file_info final date
+#' @noRd
+#' @param fi   file_info
+#' @returns final date
 .fi_max_date <- function(fi) {
     .fi_switch(
         fi = fi,
@@ -182,7 +248,10 @@ NULL
         derived_cube = max(.as_date(fi[["end_date"]]))
     )
 }
-
+#' @title Get file_info timeline
+#' @noRd
+#' @param fi   file_info
+#' @returns timeline
 .fi_timeline <- function(fi) {
     .fi_switch(
         fi = fi,
@@ -190,28 +259,40 @@ NULL
         derived_cube = .as_date(c(fi[["start_date"]], fi[["end_date"]]))
     )
 }
-
+#' @title Get file_info file paths
+#' @noRd
+#' @param fi   file_info
+#' @returns file paths
 .fi_paths <- function(fi) {
     .as_chr(fi[["path"]])
 }
-
+#' @title Get first file_info file path
+#' @noRd
+#' @param fi   file_info
+#' @returns first file path
 .fi_path <- function(fi) {
     .as_chr(fi[["path"]][[1]])
 }
-
-.fi_as_sf <- function(fi) {
-    .bbox_as_sf(.bbox(fi))
-}
-
+#' @title Filter file_info for a temporal interval
+#' @noRd
+#' @param fi   file_info
+#' @param start_date start date of the interval
+#' @param end_date end date of the interval
+#' @returns file_info for the chosen interval
 .fi_during <- function(fi, start_date, end_date) {
     fi_tl <- .fi_timeline(fi)
-   .fi_switch(
+    .fi_switch(
         fi = fi,
         eo_cube = .between(fi_tl, start_date[[1]], end_date[[1]]),
         derived_cube = all(.between(fi_tl, start_date[[1]], end_date[[1]]))
     )
 }
-
+#' @title Filter file_info for a temporal interval
+#' @noRd
+#' @param fi   file_info
+#' @param start_date start date of the interval
+#' @param end_date end date of the interval
+#' @returns file_info for the chosen interval
 .fi_filter_interval <- function(fi, start_date, end_date) {
     if (!.has(start_date)) {
         start_date <- .fi_min_date(fi)
@@ -227,7 +308,11 @@ NULL
     }
     fi[dates_in_fi, ]
 }
-
+#' @title Filter file_info for a set of dates
+#' @noRd
+#' @param fi   file_info
+#' @param dates selected dates
+#' @returns file_info for the chosen set of dates
 .fi_filter_dates <- function(fi, dates) {
     dates <- .as_date(dates)
     dates_in_fi <- dates %in% .fi_timeline(fi)
@@ -237,60 +322,45 @@ NULL
     }
     fi[.fi_timeline(fi) %in% dates, ]
 }
-
-.fi_intersects <- function(fi, roi) {
-    .intersects(.fi_as_sf(fi), .roi_as_sf(roi))
-}
-
-.fi_filter_spatial <- function(fi, roi) {
-    features_in_fi <- .fi_intersects(fi = fi, roi = roi)
-    if (!any(features_in_fi)) {
-        stop("no feature intersects informed roi")
-    }
-    fi[features_in_fi, ]
-}
-
+#' @title Read a block based in a file info
+#' @noRd
+#' @param fi   file_info
+#' @param band selected band
+#' @param block selected block
+#' @returns image values for the selected band and block
 .fi_read_block <- function(fi, band, block) {
     band <- band[[1]]
     # Stops if no band is found
     fi <- .fi_filter_bands(fi = fi, bands = band)
     files <- .fi_paths(fi)
-
-    #
     # Log here
-    #
     .debug_log(
         event = "start_block_data_read",
         key = "band",
         value = band
     )
-
-
     # Read values from all files in file_info
     values <- .raster_read_rast(files = files, block = block)
-
-
-    #
     # Log here
-    #
     .debug_log(
         event = "end_block_data_read",
         key = "band",
         value = band
     )
-
     # Return values
     values
 }
-
+#' @title Does file_info include cloud band?
+#' @noRd
+#' @param fi   file_info
+#' @returns TRUE/FALSE
 .fi_contains_cloud <- function(fi) {
     .band_cloud() %in% .fi_bands(fi)
 }
-
+#' @title Is file_info complete?
+#' @noRd
+#' @param fi   file_info
+#' @returns TRUE/FALSE
 .fi_is_complete <- function(fi) {
     length(unique(.by(fi, col = "band", .fi_timeline))) <= 1
 }
-
-.fi_same_bbox <- function(fi, tolerance) {
-    all(slider::slide_lgl(fi, .bbox_equal, .bbox(fi), tolerance = tolerance))
-}
