@@ -23,13 +23,20 @@ NULL
 #' @export
 .tile.raster_cube <- function(cube) {
     cube <- .cube(cube)
-    if (nrow(cube) >= 1) return(cube[1, ])
-    cube
+    cube[1, ]
+}
+#' @export
+.tile.default <- function(cube) {
+    cube <- tibble::as_tibble(cube)
+    cube <- .cube_find_class(cube)
+    tile <- .tile(cube)
+    return(tile)
 }
 
-#  Tile field accessors
-#  These functions enable access components of tiles. A
-#
+#' @title Get source cloud provider for a tile
+#' @noRd
+#' @param tile A tile.
+#' @return Source cloud provider
 .tile_source <- function(tile) {
     UseMethod(".tile_source", tile)
 }
@@ -38,21 +45,51 @@ NULL
     tile <- .tile(tile)
     .as_chr(tile[["source"]])
 }
-#
+#' @export
+.tile_source.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    source <- .tile_source(tile)
+    return(source)
+}
+#' @title Get image collection for a tile
+#' @noRd
+#' @param tile A tile.
+#' @return Image collection
 .tile_collection <- function(tile) {
     UseMethod(".tile_collection", tile)
 }
-
 #' @export
 .tile_collection.raster_cube <- function(tile) {
     tile <- .tile(tile)
     .as_chr(tile[["collection"]])
 }
-
-#
+#' @export
+.tile_collection.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    collection <- .tile_collection(tile)
+    return(collection)
+}
+#' @title Get/Set tile name
+#' @noRd
+#' @param tile A tile.
+#' @return Name of the tile
 .tile_name <- function(tile) {
     UseMethod(".tile_name", tile)
 }
+#' @export
+.tile_name.raster_cube <- function(tile) {
+    tile <- .tile(tile)
+    .as_chr(tile[["tile"]])
+}
+#' @export
+.tile_name.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    name <- .tile_name(tile)
+    return(name)
+}
 `.tile_name<-` <- function(tile, value) {
     UseMethod(".tile_name<-", tile)
 }
@@ -62,36 +99,48 @@ NULL
     tile[["tile"]] <- .as_chr(value)
     tile
 }
-#
-.tile_name.raster_cube <- function(tile) {
-    tile <- .tile(tile)
-    .as_chr(tile[["tile"]])
-}
-#
+#' @title Get tile number of columns
+#' @noRd
+#' @param tile A tile.
+#' @return Number of columns
 .tile_ncols <- function(tile) {
     UseMethod(".tile_ncols", tile)
 }
 #' @export
 .tile_ncols.raster_cube <- function(tile) {
     tile <- .tile(tile)
-    if ("ncols" %in% tile) {
-        return(.ncols(tile))
-    }
     .ncols(.fi(tile))
 }
-#
+#' @export
+.tile_ncols.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    ncols <- .tile_ncols(tile)
+    return(ncols)
+}
+#' @title Get tile number of rows
+#' @noRd
+#' @param tile A tile.
+#' @return Number of rows
 .tile_nrows <- function(tile) {
     UseMethod(".tile_nrows", tile)
 }
 #' @export
 .tile_nrows.raster_cube <- function(tile) {
     tile <- .tile(tile)
-    if ("nrows" %in% tile) {
-        return(.nrows(tile))
-    }
     .nrows(.fi(tile))
 }
-#
+#' @export
+.tile_nrows.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    nrows <- .tile_nrows(tile)
+    return(nrows)
+}
+#' @title Get tile size
+#' @noRd
+#' @param tile A tile.
+#' @return Size (list of nrows x ncols)
 .tile_size <- function(tile) {
     UseMethod(".tile_size", tile)
 }
@@ -99,7 +148,17 @@ NULL
 .tile_size.raster_cube <- function(tile) {
     list(ncols = .tile_ncols(tile), nrows = .tile_nrows(tile))
 }
-#
+#' @export
+.tile_size.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    size <- .tile_size(tile)
+    return(size)
+}
+#' @title Get X resolution
+#' @noRd
+#' @param tile A tile.
+#' @return x resolution
 .tile_xres <- function(tile) {
     UseMethod(".tile_xres", tile)
 }
@@ -108,7 +167,17 @@ NULL
     tile <- .tile(tile)
     .xres(.fi(tile))
 }
-#
+#' @export
+.tile_xres.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    xres <- .tile_xres(tile)
+    return(xres)
+}
+#' @title Get Y resolution
+#' @noRd
+#' @param tile A tile.
+#' @return y resolution
 .tile_yres <- function(tile) {
     UseMethod(".tile_yres", tile)
 }
@@ -117,7 +186,54 @@ NULL
     tile <- .tile(tile)
     .yres(.fi(tile))
 }
-#
+#' @export
+.tile_yres.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    yres <- .tile_yres(tile)
+    return(yres)
+}
+
+#' @title Update tile labels
+#' @noRd
+#' @param tile   A tile.
+#' @param labels A character vector with new labels
+#' @return vector of labels
+.tile_update_label <- function(tile, labels) {
+    UseMethod(".tile_update_label", tile)
+}
+
+#' @export
+.tile_update_label.class_cube <- function(tile, labels) {
+    # Open classified raster
+    tile_rast <- .raster_open_rast(.tile_path(tile))
+    # Get frequency values
+    freq_tbl <- .raster_freq(tile_rast)
+    # Get tile labels
+    tile_labels <- .tile_labels(tile)
+    if (is.null(names(tile_labels))) {
+        names(tile_labels) <- seq_along(tile_labels)
+    }
+    # Get new labels values
+    tile_labels <- tile_labels[.as_chr(freq_tbl[["value"]])]
+    # Set new labels
+    .tile_labels(tile) <- tile_labels
+    # Return tile with updated labels
+    return(tile)
+}
+
+#' @export
+.tile_update_label.default <- function(tile, labels) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_update_label(tile, labels)
+    return(tile)
+}
+
+#' @title Get/Set labels
+#' @noRd
+#' @param tile A tile.
+#' @return vector of labels
 .tile_labels <- function(tile) {
     UseMethod(".tile_labels", tile)
 }
@@ -126,6 +242,13 @@ NULL
     tile <- .tile(tile)
     tile[["labels"]][[1]]
 }
+#' @export
+.tile_labels.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    labels <- .tile_labels(tile)
+    return(labels)
+}
 #
 `.tile_labels<-` <- function(tile, value) {
     UseMethod(".tile_labels<-", tile)
@@ -152,6 +275,13 @@ NULL
     tile <- .tile(tile)
     .fi_min_date(.fi(tile))
 }
+#' @export
+.tile_start_date.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    start_date <- .tile_start_date(tile)
+    return(start_date)
+}
 #'
 #' @title Get end date from file_info.
 #' @name .tile_end_date
@@ -168,14 +298,19 @@ NULL
     tile <- .tile(tile)
     .fi_max_date(.fi(tile))
 }
-
+#' @export
+.tile_end_date.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    end_date <- .tile_end_date(tile)
+    return(end_date)
+}
 #' @title Get fid from tile
 #' @name .tile_fid
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
-#'
-#' @return date
+#' @return file ID
 .tile_fid <- function(tile) {
     UseMethod(".tile_fid", tile)
 }
@@ -184,12 +319,18 @@ NULL
     tile <- .tile(tile)
     .fi_fid(.fi(tile))
 }
+#' @export
+.tile_fid.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    fid <- .tile_fid(tile)
+    return(fid)
+}
 #' @title Get unique timeline from file_info.
 #' @name .tile_timeline
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
-#'
 #' @return a timeline
 .tile_timeline <- function(tile) {
     UseMethod(".tile_timeline", tile)
@@ -199,6 +340,19 @@ NULL
     tile <- .tile(tile)
     sort(unique(.fi_timeline(.fi(tile))))
 }
+#' @export
+.tile_timeline.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    timeline <- .tile_timeline(tile)
+    return(timeline)
+}
+#' @title Check if tile is complete
+#' @name .tile_is_complete
+#' @keywords internal
+#' @noRd
+#' @param tile A tile.
+#' @return TRUE/FALSE
 .tile_is_complete <- function(tile) {
     UseMethod(".tile_is_complete", tile)
 }
@@ -207,19 +361,24 @@ NULL
     tile <- .tile(tile)
     .fi_is_complete(.fi(tile))
 }
-#' @title Get sorted unique bands from file_info.
+#' @export
+.tile_is_complete.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    is_complete <- .tile_is_complete(tile)
+    return(is_complete)
+}
+#' @title Get path of first asset from file_info.
 #' @name .tile_path
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
 #' @param band A band in the tile
 #' @param date A date in the tile
-#'
 #' @return Path of first asset in `file_info`
 .tile_path <- function(tile, band = NULL, date = NULL) {
     UseMethod(".tile_path", tile)
 }
-
 #' @export
 .tile_path.raster_cube <- function(tile, band = NULL, date = NULL) {
     tile <- .tile(tile)
@@ -234,6 +393,20 @@ NULL
     # Return path
     path
 }
+#' @export
+.tile_path.default <- function(tile, band = NULL, date = NULL) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    path <- .tile_path(tile, band, date)
+    return(path)
+}
+#' @title Get all file paths from file_info.
+#' @name .tile_paths
+#' @keywords internal
+#' @noRd
+#' @param tile A tile.
+#' @param bands Required bands
+#' @return Paths of assets in `file_info` filtered by bands
 .tile_paths <- function(tile, bands = NULL) {
     UseMethod(".tile_paths", tile)
 }
@@ -246,15 +419,20 @@ NULL
     # Get assets path
     paths <- .fi_paths(.fi(tile))
     # Return paths
-    paths
+    return(paths)
+}
+#' @export
+.tile_paths.default <- function(tile, bands = NULL) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    paths <- .tile_paths(tile, bands)
+    return(paths)
 }
-
 #' @title Get unique satellite name from tile.
 #' @name .tile_satellite
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
-#'
 #' @return satellite name in the tile
 .tile_satellite <- function(tile) {
     UseMethod(".tile_satellite", tile)
@@ -265,7 +443,13 @@ NULL
     tile <- .tile(tile)
     .as_chr(tile[["satellite"]])
 }
-
+#' @export
+.tile_satellite.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    satellite <- .tile_satellite(tile)
+    return(satellite)
+}
 #' @title Get unique sensor name from tile.
 #' @name .tile_sensor
 #' @keywords internal
@@ -276,19 +460,23 @@ NULL
 .tile_sensor <- function(tile) {
     UseMethod(".tile_sensor", tile)
 }
-
 #' @export
 .tile_sensor.raster_cube <- function(tile) {
     tile <- .tile(tile)
     .as_chr(tile[["sensor"]])
 }
-
+#' @export
+.tile_sensor.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    sensor <- .tile_sensor(tile)
+    return(sensor)
+}
 #' @title Get sorted unique bands from file_info.
 #' @name .tile_bands
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
-#'
 #' @return names of bands in the tile
 .tile_bands <- function(tile, add_cloud = TRUE) {
     UseMethod(".tile_bands", tile)
@@ -297,10 +485,18 @@ NULL
 .tile_bands.raster_cube <- function(tile, add_cloud = TRUE) {
     tile <- .tile(tile)
     bands <- unique(.fi_bands(.fi(tile)))
-    if (add_cloud) return(bands)
+    if (add_cloud) {
+        return(bands)
+    }
     setdiff(bands, .band_cloud())
 }
-
+#' @export
+.tile_bands.default <- function(tile, add_cloud = TRUE) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    bands <- .tile_bands(tile, add_cloud)
+    return(bands)
+}
 #' @title Set bands in tile file_info.
 #' @rdname .tile_bands
 #' @keywords internal
@@ -350,6 +546,13 @@ NULL
         derived_class = .tile_derived_class(tile), band = band[[1]]
     )
 }
+#' @export
+.tile_band_conf.default <- function(tile, band) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    band_conf <- .tile_band_conf(tile, band)
+    return(band_conf)
+}
 #'
 #' @title Filter file_info entries of a given \code{band}.
 #' @name .tile_filter_bands
@@ -374,6 +577,19 @@ NULL
     .fi(tile) <- .fi_filter_bands(fi = .fi(tile), bands = .band_derived(bands))
     tile
 }
+#' @export
+.tile_filter_bands.class_cube <- function(tile, bands) {
+    tile <- .tile(tile)
+    .fi(tile) <- .fi_filter_bands(fi = .fi(tile), bands = "class")
+    tile
+}
+#' @export
+.tile_filter_bands.default <- function(tile, bands) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_filter_bands(tile, bands)
+    return(tile)
+}
 #'
 #' @title Get crs from tile
 #' @name .tile_crs
@@ -381,7 +597,7 @@ NULL
 #' @noRd
 #' @param tile A tile.
 #'
-#' @return character
+#' @return CRS
 .tile_crs <- function(tile) {
     UseMethod(".tile_crs", tile)
 }
@@ -390,6 +606,20 @@ NULL
     tile <- .tile(tile)
     .crs(tile)
 }
+#' @export
+.tile_crs.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    crs <- .tile_crs(tile)
+    return(crs)
+}
+#' @title Get bbox from tile
+#' @name .tile_bbox
+#' @keywords internal
+#' @noRd
+#' @param tile A tile.
+#'
+#' @return bbox
 .tile_bbox <- function(tile, as_crs = NULL) {
     UseMethod(".tile_bbox", tile)
 }
@@ -398,6 +628,13 @@ NULL
     tile <- .tile(tile)
     .bbox(tile, as_crs = as_crs)
 }
+#' @export
+.tile_bbox.default <- function(tile, as_crs = NULL) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    bbox <- .tile_bbox(tile, as_crs = as_crs)
+    return(bbox)
+}
 #' @title Convert tile \code{bbox} to a sf polygon object.
 #' @noRd
 #' @param tile A tile.
@@ -409,6 +646,13 @@ NULL
 .tile_as_sf.raster_cube <- function(tile, as_crs = NULL) {
     .bbox_as_sf(.tile_bbox(tile), as_crs = as_crs)
 }
+#' @export
+.tile_as_sf.default <- function(tile, as_crs = NULL) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    sf_obj <- .tile_as_sf(tile, as_crs = as_crs)
+    return(sf_obj)
+}
 #'
 #' @title Does tile \code{bbox} intersect \code{roi} parameter?
 #' @name .tile_intersects
@@ -425,6 +669,13 @@ NULL
 .tile_intersects.raster_cube <- function(tile, roi) {
     .intersects(.tile_as_sf(tile), .roi_as_sf(roi))
 }
+#' @export
+.tile_intersects.default <- function(tile, roi) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    intersects <- .tile_intersects(tile, roi)
+    return(intersects)
+}
 #' @title Is tile inside roi?
 #' @name .tile_within
 #' @keywords internal
@@ -440,22 +691,12 @@ NULL
 .tile_within.raster_cube <- function(tile, roi) {
     .within(.tile_as_sf(tile), .roi_as_sf(roi))
 }
-#' @title Filter file_info entries that intersect roi.
-#' @name .tile_filter_spatial
-#' @keywords internal
-#' @noRd
-#' @param tile A tile.
-#' @param roi A region of interest (ROI).
-#'
-#' @return tile
-.tile_filter_spatial <- function(tile, roi) {
-    UseMethod(".tile_filter_spatial", tile)
-}
 #' @export
-.tile_filter_spatial.raster_cube <- function(tile, roi) {
-    tile <- .tile(tile)
-    .fi(tile) <- .fi_filter_spatial(fi = .fi(tile), roi = roi)
-    tile
+.tile_within.default <- function(tile, roi) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    within <- .tile_within(tile, roi)
+    return(within)
 }
 #'
 #' @title Is any date of tile's timeline between 'start_date'
@@ -477,6 +718,13 @@ NULL
         fi = .fi(tile), start_date = start_date, end_date = end_date
     ))
 }
+#' @export
+.tile_during.default <- function(tile, start_date, end_date) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    result <- .tile_during(tile, start_date, end_date)
+    return(result)
+}
 #'
 #' @title Filter file_info entries by 'start_date' and 'end_date.'
 #' @name .tile_filter_interval
@@ -497,6 +745,13 @@ NULL
     )
     tile
 }
+#' @export
+.tile_filter_interval.default <- function(tile, start_date, end_date) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_filter_interval(tile, start_date, end_date)
+    return(tile)
+}
 #'
 #' @title Filter file_info entries by date
 #' @name .tile_filter_dates
@@ -627,15 +882,21 @@ NULL
     # Return values
     return(values)
 }
+#' @export
+.tile_read_block.default <- function(tile, band, block) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_read_block(tile, band, block)
+    return(tile)
+}
 #'
 #' @title Read and preprocess a block of cloud values from
-#' file_info rasters.
+#'        file_info rasters.
 #' @name .tile_cloud_read_block
 #' @keywords internal
 #' @noRd
 #' @param tile A tile.
 #' @param block A block list with (col, row, ncols, nrows).
-#'
 #' @return set of values of a band of a tile in a block
 .tile_cloud_read_block <- function(tile, block) {
     UseMethod(".tile_cloud_read_block", tile)
@@ -666,7 +927,7 @@ NULL
         values <- values %in% interp_values
     } else {
         values <- matrix(bitwAnd(values, sum(2^interp_values)) > 0,
-                         nrow = length(values)
+            nrow = length(values)
         )
     }
     #
@@ -680,14 +941,21 @@ NULL
     # Return values
     return(values)
 }
+#' @export
+.tile_cloud_read_block.default <- function(tile, block) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_cloud_read_block(tile, block)
+    return(tile)
+}
 #' @title Create chunks of a tile to be processed
 #' @name .tile_chunks_create
 #' @keywords internal
 #' @noRd
 #' @param tile tile to be processed
 #' @param overlap overlap between tiles
+#' @param block   Current block
 #' @return set of chunks to be read from the file
-
 .tile_chunks_create <- function(tile, overlap, block = NULL) {
     # Get block size
     block <- .default(
@@ -702,11 +970,18 @@ NULL
         image_bbox = .tile_bbox(tile)
     )
 }
-
+#' @title Get tile from file
+#' @keywords internal
+#' @noRd
+#' @param file  Raster file
+#' @param base_tile  reference tile used in the operation
+#' @param band Spectral band
+#' @param update_bbox  should bbox be updated?
+#' @param labels Labels for classified cube
+#' @return set of values of a band of a tile in a block
 .tile_from_file <- function(file, base_tile, band, update_bbox, labels = NULL) {
     UseMethod(".tile_from_file", base_tile)
 }
-
 #' @export
 .tile_from_file.eo_cube <- function(file, base_tile, band, update_bbox,
                                     labels = NULL) {
@@ -719,7 +994,6 @@ NULL
         update_bbox = update_bbox
     )
 }
-
 #' @export
 .tile_from_file.derived_cube <- function(file, base_tile, band, update_bbox,
                                          labels = NULL) {
@@ -732,7 +1006,15 @@ NULL
         update_bbox = update_bbox
     )
 }
-
+#' @export
+.tile_from_file.default <- function(file, base_tile, band, update_bbox,
+                                    labels = NULL) {
+    base_tile <- tibble::as_tibble(base_tile)
+    base_tile <- .cube_find_class(base_tile)
+    base_tile <- .tile_from_file(file, base_tile, band, update_bbox,
+                            labels = NULL)
+    return(base_tile)
+}
 #' @title read an EO tile from files
 #' @name .tile_eo_from_files
 #' @keywords internal
@@ -816,7 +1098,6 @@ NULL
 #' @return a new tile
 .tile_derived_from_file <- function(file, band, base_tile, derived_class,
                                     labels = NULL, update_bbox = FALSE) {
-
     if (derived_class %in% c("probs_cube", "variance_cube")) {
         # Open first block file to be merged
         r_obj <- .raster_open_rast(file)
@@ -851,6 +1132,45 @@ NULL
     # Set tile class and return tile
     .cube_set_class(base_tile, .conf_derived_s3class(derived_class))
 }
+
+#' @title Create a tile derived from a segment file
+#' @name .tile_segments_from_file
+#' @keywords internal
+#' @noRd
+#' @param file  file to be merged
+#' @param band  band to be used in the tile
+#' @param base_tile  reference tile used in the operation
+#' @param vector_class class of the vector tile
+#' @param update_bbox  should bbox be updated?
+#' @return a new tile
+.tile_segments_from_file <- function(file, band, base_tile, vector_class,
+                                     labels = NULL, update_bbox = FALSE) {
+    v_obj <- .vector_read_vec(file_path = file)
+    base_tile <- .tile(base_tile)
+    bbox <- .vector_bbox(v_obj)
+    if (update_bbox) {
+        # Update spatial bbox
+        .xmin(base_tile) <- bbox[["xmin"]]
+        .xmax(base_tile) <- bbox[["xmax"]]
+        .ymin(base_tile) <- bbox[["ymin"]]
+        .ymax(base_tile) <- bbox[["ymax"]]
+        .crs(base_tile) <- .vector_crs(v_obj, wkt = TRUE)
+    }
+    # Update labels before file_info
+    .tile_labels(base_tile) <- labels
+    # Update file_info
+    .vi(base_tile) <- .vi_segment_from_file(
+        file = file,
+        base_tile = base_tile,
+        band = band,
+        start_date = .tile_start_date(base_tile),
+        end_date = .tile_end_date(base_tile)
+    )
+    # Set tile class and return tile
+    seg_classes <- c(.conf_vector_s3class(vector_class), class(base_tile))
+    .cube_set_class(base_tile, seg_classes)
+}
+
 #' @title Write values of a derived tile from a set of blocks
 #' @name .tile_derived_merge_blocks
 #' @keywords internal
@@ -862,7 +1182,7 @@ NULL
 #' @param derived_class class of the derived tile
 #' @param block_files  files that host the blocks
 #' @param multicores  number of parallel processes
-#' @param update_bbox  should bbox be updated?
+#' @param update_bbox   should bbox be updated?
 #' @return a new tile with files written
 .tile_derived_merge_blocks <- function(file, band, labels, base_tile,
                                        derived_class, block_files, multicores,
@@ -909,6 +1229,40 @@ NULL
     tile
 }
 
+#' @title Write values of a derived tile from a set of blocks segments
+#' @name .tile_segment_merge_blocks
+#' @keywords internal
+#' @noRd
+#' @param block_files blocks to be merged
+#' @param base_tile  reference tile used in the operation
+#' @param band  band to be used in the tile
+#' @param derived_class class of the derived tile
+#' @param out_file output file name
+#' @param update_bbox  should bbox be updated?
+#' @return a new tile with files written
+.tile_segment_merge_blocks <- function(block_files, base_tile, band, vector_class,
+                                       out_file, update_bbox = FALSE) {
+    base_tile <- .tile(base_tile)
+    # Read all blocks file
+    vec_segments <- purrr::map_dfr(block_files, .vector_read_vec)
+    # Define an unique ID
+    vec_segments[["pol_id"]] <- seq_len(nrow(vec_segments))
+    # Write all segments
+    .vector_write_vec(v_obj = vec_segments, file_path = out_file)
+    # Create tile based on template
+    tile <- .tile_segments_from_file(
+        file = out_file,
+        band = band,
+        base_tile = base_tile,
+        vector_class = vector_class,
+        update_bbox = update_bbox
+    )
+    # If all goes well, delete block files
+    unlink(block_files)
+    # Return derived tile
+    tile
+}
+
 #' @title Given a labelled cube, return the band information
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @param tile   Tile of a data cube
@@ -918,7 +1272,6 @@ NULL
 #' @keywords internal
 #' @noRd
 .tile_area_freq <- function(tile) {
-
     UseMethod(".tile_area_freq", tile)
 }
 #' @export
@@ -930,7 +1283,17 @@ NULL
     # Return frequencies
     freq
 }
-
+#' @export
+.tile_area_freq.raster_cube <- function(tile) {
+    stop("Cube is not a classified cube")
+}
+#' @export
+.tile_area_freq.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    tile <- .tile_area_freq(tile)
+    return(tile)
+}
 #' @title Given a tile and a band, return a set of values for chosen location
 #' @name .tile_extract
 #' @noRd
@@ -965,30 +1328,33 @@ NULL
 #'
 #' @description Given a data cube, retrieve the time series of XY locations
 #'
-#' @param tile        Metadata about a data cube (one tile)
-#' @param band        Name of the band to the retrieved
-#' @param seg_pols    Segments as polygons
-#' @param aggreg_fn   Aggregation function for joining polygon values
+#' @param seg_tile_band    Tibble with information on raster and vector files
 #'
-#' @return Data.frame with aggregated values per polygon.
+#' @return Data.frame with values per polygon.
 #'
-.tile_extract_segments <- function(tile, band, seg_pols, aggreg_fn) {
-    # Create a stack object
-    r_obj <- .raster_open_rast(.tile_paths(tile = tile, bands = band))
-    n_names <- length(names(r_obj))
-    names(r_obj) <- c(1:n_names)
-    # Convert to SpatVectors
-    class(seg_pols) <- c("sf", class(seg_pols))
+.tile_extract_segments <- function(seg_tile_band) {
+    # Create a SpatRaster object
+    r_obj <- .raster_open_rast(seg_tile_band[["files"]][[1]])
+    names(r_obj) <- paste0(seg_tile_band[["band"]], "-",
+                           seq_len(terra::nlyr(r_obj)))
+    segments <- .vector_read_vec(seg_tile_band[["segs_path"]])
     # Extract the values
-    values <- as.matrix(exactextractr::exact_extract(
+    values <- exactextractr::exact_extract(
         x = r_obj,
-        y = seg_pols,
-        fun = aggreg_fn
-    ))
+        y = segments,
+        fun = NULL,
+        include_cols = "pol_id"
+    )
+    values <- dplyr::bind_rows(values)
+    values <- dplyr::select(values, -"coverage_fraction")
     # Return values
-    return(values)
+    return(as.matrix(values))
 }
-
+#' @title Check if tile contains cloud band
+#' @keywords internal
+#' @noRd
+#' @param tile input tile
+#' @return TRUE/FALSE
 .tile_contains_cloud <- function(tile) {
     tile <- .tile(tile)
     .fi_contains_cloud(.fi(tile))
@@ -999,14 +1365,16 @@ NULL
 #' @noRd
 #' @param tile input tile
 #' @param verbose     TRUE/FALSE
-#'
 #' @return start time for classification
 #'
 .tile_classif_start <- function(tile, verbose) {
     start_time <- Sys.time()
-    if (verbose)
-        message("Starting classification of tile '",
-                tile[["tile"]], "' at ", start_time)
+    if (verbose) {
+        message(
+            "Starting classification of tile '",
+            tile[["tile"]], "' at ", start_time
+        )
+    }
     return(start_time)
 }
 #' @title Measure classification time
@@ -1020,12 +1388,15 @@ NULL
 #' @return end time for classification
 #'
 .tile_classif_end <- function(tile, start_time, verbose) {
+    end_time <- Sys.time()
     if (verbose) {
-        end_time <- Sys.time()
         message("Tile '", tile[["tile"]], "' finished at ", end_time)
-        message("Elapsed time of ",
-                format(round(end_time - start_time, digits = 2)))
+        message(
+            "Elapsed time of ",
+            format(round(end_time - start_time, digits = 2))
+        )
         message("")
     }
-    return(end_time)
+    return(invisible(end_time))
 }
+
