@@ -1,10 +1,10 @@
 #' @title  Include leaflet to view images (BW or RGB)
-#' @name .view_image
+#' @name .view_image_raster
 #' @keywords internal
 #' @noRd
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
-#' @param  cube          Cube to be plotted
+#' @param  cube          Cube to be plotted (raster cube)
 #' @param  class_cube    Classified cube to be overlayed on top on image
 #' @param  tiles         Tiles to be plotted (in case of a multi-tile cube).
 #' @param  dates         Dates to be plotted.
@@ -13,23 +13,22 @@
 #' @param  green         Band for green color.
 #' @param  blue          Band for blue color.
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided in the configuration file.
-#' @param  segments      Segment list obtained by \link{sits_segmentation}
+#' @param  palette       Palette provided in the configuration file.
 #' @param  view_max_mb   Maximum size of leaflet to be visualized
 #'
 #' @return               A leaflet object.
 #'
-.view_image <- function(cube,
+.view_image_raster <- function(cube,
                         class_cube,
                         tiles,
                         dates,
-                        band = NULL,
-                        red = NULL,
-                        green = NULL,
-                        blue = NULL,
+                        band,
+                        red,
+                        green,
+                        blue,
                         legend,
-                        color_palette,
-                        segments,
+                        palette,
+                        opacity,
                         view_max_mb) {
     # filter the tiles to be processed
     cube <- .view_filter_tiles(cube, tiles)
@@ -47,45 +46,45 @@
     leaf_map <- .view_add_basic_maps()
     # get names of basic maps
     base_maps <- .view_get_base_maps(leaf_map)
-    # add B/W band, class cube, and segments
-    if (!purrr::is_null(band))
+    # add B/W band if required
+    # create a leaflet for B/W bands
+    if (!purrr::is_null(band)) {
         leaf_map <- leaf_map |>
-        .view_bw_band(
-            cube = cube,
-            band = band,
-            dates = dates,
-            output_size = output_size,
-            color_palette = color_palette)
-    else
+            .view_bw_band(
+                cube = cube,
+                band = band,
+                dates = dates,
+                output_size = output_size,
+                palette = palette
+            )
+    } else {
+        # add RGB bands if required
         # create a leaflet for RGB bands
         leaf_map <- leaf_map |>
-        .view_rgb_bands(
-            cube = cube,
-            red = red,
-            green = green,
-            blue = blue,
-            dates = dates,
-            output_size = output_size)
+            .view_rgb_bands(
+                cube = cube,
+                red = red,
+                green = green,
+                blue = blue,
+                dates = dates,
+                output_size = output_size
+            )
+    }
     # include class cube if available
     leaf_map <- leaf_map |>
         .view_class_cube(
             class_cube = class_cube,
             tiles = tiles,
             legend = legend,
-            color_palette = color_palette,
-            output_size = output_size) |>
-        # include segments, if available
-        .view_segments(
-            segments = segments,
-            legend = legend,
-            color_palette = color_palette
+            palette = palette,
+            opacity = opacity,
+            output_size = output_size
         )
     # get overlay groups
     overlay_groups <- .view_add_overlay_grps(
         cube = cube,
         dates = dates,
-        class_cube = class_cube,
-        segments = segments
+        class_cube = class_cube
     )
     # add layers control to leafmap
     leaf_map <- leaf_map |>
@@ -94,48 +93,53 @@
             overlayGroups = overlay_groups,
             options = leaflet::layersControlOptions(collapsed = FALSE)
         ) |>
-    # add legend to leaf_map
+        # add legend to leaf_map
         .view_add_legend(
-            class_cube = class_cube,
-            segments = segments,
-            color_palette = color_palette
+            cube = class_cube,
+            legend = legend,
+            palette = palette
         )
     return(leaf_map)
 }
-
-#' @title  Include leaflet to view RGB image
-#' @name .view_rgb_image
+#' @title  Include leaflet to view vector images
+#' @name .view_image_vector
 #' @keywords internal
 #' @noRd
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
-#' @param  cube          Cube to be plotted
-#' @param  class_cube    Classified cube to be overlayed on top on image
+#' @param  cube          Cube to be plotted (vector or raster cube)
 #' @param  tiles         Tiles to be plotted (in case of a multi-tile cube).
 #' @param  dates         Dates to be plotted.
+#' @param  band          For plotting grey images.
 #' @param  red           Band for red color.
 #' @param  green         Band for green color.
 #' @param  blue          Band for blue color.
+#' @param  class_cube    Classified cube to be overlayed on top on image
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided in the configuration file.
-#' @param  segments      Segment list obtained by \link{sits_segmentation}
+#' @param  palette       Palette provided in the configuration file.
+#' @param  seg_color     Color for segments
+#' @param  line_width    Line width for segments
+#' @param  fill_opacity  Opacity of segment fill
 #' @param  view_max_mb   Maximum size of leaflet to be visualized
-.view_rgb_image <- function(cube,
-                            class_cube,
-                            tiles,
-                            dates,
-                            red,
-                            green,
-                            blue,
-                            legend,
-                            color_palette,
-                            segments,
-                            view_max_mb) {
-
-    # filter the tiles
+#'
+#' @return               A leaflet object.
+#'
+.view_image_vector <- function(cube,
+                               tiles,
+                               dates,
+                               band,
+                               red,
+                               green,
+                               blue,
+                               class_cube,
+                               legend,
+                               palette,
+                               opacity,
+                               seg_color,
+                               line_width,
+                               view_max_mb) {
+    # filter the tiles to be processed
     cube <- .view_filter_tiles(cube, tiles)
-    # set the dates
-    dates <- .view_set_dates(cube, dates)
     # check the view_max_mb parameter
     view_max_mb <- .view_set_max_mb(view_max_mb)
     # find out if resampling is required (for big images)
@@ -148,45 +152,78 @@
     leaf_map <- .view_add_basic_maps()
     # get names of basic maps
     base_maps <- .view_get_base_maps(leaf_map)
+    # add B/W band if required
+    # create a leaflet for B/W bands
+    if (!purrr::is_null(band)) {
+        if (purrr::is_null(dates))
+            dates <- .cube_timeline(cube)[[1]][1]
+        leaf_map <- leaf_map |>
+            .view_bw_band(
+                cube = cube,
+                band = band,
+                dates = dates,
+                output_size = output_size,
+                palette = palette
+            )
+    }
+    # add RGB bands if required
     # create a leaflet for RGB bands
+    if (!purrr::is_null(red) &&
+        !purrr::is_null(green) &&
+        !purrr::is_null(blue)) {
+        # update the dates parameter
+        if (purrr::is_null(dates))
+            dates <- .cube_timeline(cube)[[1]][1]
+        leaf_map <- leaf_map |>
+            .view_rgb_bands(
+                cube = cube,
+                red = red,
+                green = green,
+                blue = blue,
+                dates = dates,
+                output_size = output_size
+            )
+    }
+    # include segments (and class cube if available)
     leaf_map <- leaf_map |>
-        .view_rgb_bands(
+        # include segments
+        .view_segments(
             cube = cube,
-            red = red,
-            green = green,
-            blue = blue,
-            dates = dates,
-            output_size = output_size) |>
-        # include class cube if available
+            seg_color = seg_color,
+            line_width = line_width,
+            opacity  = opacity,
+            legend = legend,
+            palette = palette
+        ) |>
         .view_class_cube(
             class_cube = class_cube,
             tiles = tiles,
             legend = legend,
-            color_palette = color_palette,
-            output_size = output_size) |>
-        # include segments, if available
-        .view_segments(
-            segments = segments,
-            legend = legend,
-            color_palette = color_palette)
+            palette = palette,
+            opacity = opacity,
+            output_size = output_size
+        )
+    # have we included base images?
+
     # get overlay groups
     overlay_groups <- .view_add_overlay_grps(
         cube = cube,
         dates = dates,
-        class_cube = class_cube,
-        segments = segments
+        class_cube = class_cube
     )
-    # add layers control
+    # add layers control to leafmap
     leaf_map <- leaf_map |>
         leaflet::addLayersControl(
             baseGroups = base_maps,
             overlayGroups = overlay_groups,
-            options = leaflet::layersControlOptions(collapsed = FALSE)) |>
-        # add legend
+            options = leaflet::layersControlOptions(collapsed = FALSE)
+        ) |>
+        # add legend to leaf_map
         .view_add_legend(
-            class_cube = class_cube,
-            segments = segments)
-
+            cube = cube,
+            legend = legend,
+            palette = palette
+        )
     return(leaf_map)
 }
 #' @title  Return the size of the imaged to be resamples for visulization
@@ -202,7 +239,6 @@
 #'
 #'
 .view_resample_size <- function(cube, ndates, view_max_mb) {
-
     # number of tiles to be merged
     ntiles <- nrow(cube)
     # estimate nrows and ncols to be merged
@@ -246,11 +282,10 @@
 #' @param  samples       Data.frame with columns "longitude", "latitude"
 #'                       and "label"
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided in the configuration file.
+#' @param  palette       Palette provided in the configuration file.
 #' @return               A leaflet object
 #'
-.view_samples <- function(samples, legend, color_palette) {
-
+.view_samples <- function(samples, legend, palette) {
     # first select unique locations
     samples <- dplyr::distinct(
         samples,
@@ -274,7 +309,7 @@
         colors <- .colors_get(
             labels = labels,
             legend = NULL,
-            color_palette = color_palette,
+            palette = palette,
             rev = TRUE
         )
     } else {
@@ -313,10 +348,10 @@
             options = leaflet::layersControlOptions(collapsed = FALSE)
         ) |>
         leaflet::addLegend("topright",
-                           pal     = factpal,
-                           values  = samples$label,
-                           title   = "Training Samples",
-                           opacity = 1
+            pal     = factpal,
+            values  = samples$label,
+            title   = "Training Samples",
+            opacity = 1
         )
     return(leaf_map)
 }
@@ -360,17 +395,20 @@
 #' @return               Valid leafmap size
 #'
 .view_set_max_mb <- function(view_max_mb) {
-
     # get the maximum number of bytes to be displayed (total)
-    if (purrr::is_null(view_max_mb))
-        view_max_mb <- .conf("leaflet_max_megabytes")
-    else
+    if (purrr::is_null(view_max_mb)) {
+        view_max_mb <- .conf("leaflet_megabytes")
+    } else {
         .check_num(
             x = view_max_mb,
             is_integer = TRUE,
-            min = 16,
-            max = 512,
-            msg = "view_max_mb should be btw 16MB and 512 MB")
+            min = .conf("leaflet_min_megabytes"),
+            max = .conf("leaflet_max_megabytes"),
+            msg = paste("view_max_mb should be btw ",
+                        .conf("leaflet_min_megabytes"), "MB and ",
+                        .conf("leaflet_max_megabytes"), "MB")
+        )
+    }
     return(view_max_mb)
 }
 #' @title  Include leaflet to view segments
@@ -380,82 +418,78 @@
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @param  leafmap       Leaflet map
-#' @param  segments      Segment list obtained by \link{sits_segmentation}
+#' @param  cube          Vector cube
+#' @param  seg_color     Color for segments boundaries
+#' @param  line_width    Line width for segments (in pixels)
+#' @param  opacity       Opacity of segment fill
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided in the configuration file.
+#' @param  palette       Palette provided in the configuration file.
 #'
 #' @return               A leaflet object
 #
 .view_segments <- function(leaf_map,
-                           segments,
+                           cube,
+                           seg_color,
+                           line_width,
+                           opacity,
                            legend,
-                           color_palette) {
-    # if there are no segments, return
-    if (purrr::is_null(segments)) {
-        return(leaf_map)
-    } else {
-        # add segments if they exist
-        # check that segments are valid
-        .check_that(
-            x = inherits(segments, c("segments")),
-            msg = "segments to be overlayed are invalid"
+                           palette) {
+    # retrieve segments on a tile basis
+    for (row in seq_len(nrow(cube))) {
+        # get tile
+        tile <- cube[row, ]
+        # retrieve the segments for this tile
+        sf_seg <- .segments_read_vec(tile)
+        # transform the segments
+        sf_seg <- sf::st_transform(
+            sf_seg,
+            crs = sf::st_crs("EPSG:4326")
         )
-        # how many tiles are there in the segments
-        tile_names <- names(segments)
-        for (tile_name in tile_names) {
-            # retrieve the segments for this tile
-            sf_seg <- segments[[tile_name]]
-            # transform the segments
-            sf_seg <- sf::st_transform(
-                sf_seg,
-                crs = sf::st_crs("EPSG:4326")
+        # create a layer with the segment borders
+        leaf_map <- leafem::addFeatures(
+            leaf_map,
+            data = sf_seg,
+            color = seg_color,
+            opacity = 1,
+            fillOpacity = 0,
+            weight = line_width,
+            group = "segments",
+        )
+        # have the segments been classified?
+        if ("class" %in% colnames(sf_seg)) {
+            # dissolve sf_seg
+            sf_seg <- sf_seg |>
+                dplyr::group_by(.data[["class"]]) |>
+                dplyr::summarise()
+            labels_seg <- sf_seg |>
+                sf::st_drop_geometry() |>
+                dplyr::select("class") |>
+                dplyr::pull()
+            # get the names of the labels
+            names(labels_seg) <- seq_along(labels_seg)
+            # obtain the colors
+            colors <- .colors_get(
+                labels = labels_seg,
+                legend = legend,
+                palette = palette,
+                rev = TRUE
+            )
+            # add a new leafmap to show polygons of segments
+            leaf_map <- leafem::addFeatures(
+                leaf_map,
+                data = sf_seg,
+                label = labels_seg,
+                color = seg_color,
+                stroke = FALSE,
+                weight = line_width,
+                opacity = 1,
+                fillColor = unname(colors),
+                fillOpacity = opacity,
+                group = "class_segments"
             )
-            # have the segments been classified?
-            if ("class" %in% colnames(sf_seg)) {
-                # dissolve sf_seg
-                sf_seg <- sf_seg |>
-                    dplyr::group_by(.data[["class"]]) |>
-                    dplyr::summarise()
-                labels_seg <- sf_seg |>
-                    sf::st_drop_geometry() |>
-                    dplyr::select("class") |>
-                    dplyr::pull()
-                # get the names of the labels
-                names(labels_seg) <- seq_along(labels_seg)
-                # obtain the colors
-                colors <- .colors_get(
-                    labels = labels_seg,
-                    legend = legend,
-                    color_palette = color_palette,
-                    rev = TRUE
-                )
-                # add a new leafmap to show polygons of segments
-                leaf_map <- leafem::addFeatures(
-                    leaf_map,
-                    data = sf_seg,
-                    label = labels_seg,
-                    color = "white",
-                    opacity = 1,
-                    fillColor = unname(colors),
-                    fillOpacity = 0.6,
-                    weight = 1,
-                    group = "segments"
-                )
-            } else {
-                leaf_map <- leafem::addFeatures(
-                    leaf_map,
-                    data = sf_seg,
-                    fillColor = "grey",
-                    color = "white",
-                    opacity = 1,
-                    fillOpacity = 0.6,
-                    weight = 1,
-                    group = "segments",
-                )
-            }
         }
-        return(leaf_map)
     }
+    return(leaf_map)
 }
 #' @title  Include leaflet to view B/W band
 #' @name .view_bw_band
@@ -467,7 +501,7 @@
 #' @param  cube          Data cube
 #' @param  band          Band to be shown
 #' @param  dates         Dates to be plotted
-#' @param  color_palette Palette to show false colors
+#' @param  palette       Palette to show false colors
 #' @param  output_size   Controls size of leaflet to be visualized
 #' @return               A leaflet object
 #
@@ -475,7 +509,7 @@
                           cube,
                           band,
                           dates,
-                          color_palette,
+                          palette,
                           output_size) {
     # obtain the raster objects for the dates chosen
     for (i in seq_along(dates)) {
@@ -490,7 +524,7 @@
                 date <- tile_dates[idx_date]
             }
             # filter by date and band
-            band_file   <- .tile_path(tile, band, date)
+            band_file <- .tile_path(tile, band, date)
             # plot a single file
             leaf_map <- .view_add_stars_image(
                 leaf_map = leaf_map,
@@ -498,14 +532,15 @@
                 tile = tile,
                 band = band,
                 date = date,
-                color_palette = color_palette,
-                output_size = output_size)
+                palette = palette,
+                output_size = output_size
+            )
         }
     }
     return(leaf_map)
 }
-#' @title  Include leaflet to view RGB band
-#' @name .view_rgb_band
+#' @title  Include leaflet to view RGB bands
+#' @name .view_rgb_bands
 #' @keywords internal
 #' @noRd
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
@@ -540,9 +575,9 @@
             }
             # filter by date and band
             # if there is only one band, RGB files will be the same
-            red_file   <- .tile_path(tile, red, date)
+            red_file <- .tile_path(tile, red, date)
             green_file <- .tile_path(tile, green, date)
-            blue_file  <- .tile_path(tile, blue, date)
+            blue_file <- .tile_path(tile, blue, date)
 
             rgb_files <- c(r = red_file, g = green_file, b = blue_file)
             st_obj <- stars::read_stars(
@@ -586,14 +621,16 @@
 #' @param  class_cube    Classified cube to be overlayed on top on image
 #' @param  tiles         Tiles to be plotted (in case of a multi-tile cube).
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided as alternative legend.
+#' @param  palette       Palette provided as alternative legend.
+#' @param  opacity       Fill opacity
 #' @param  output_size   Controls size of leaflet to be visualized
 #'
 .view_class_cube <- function(leaf_map,
                              class_cube,
                              tiles,
                              legend,
-                             color_palette,
+                             palette,
+                             opacity,
                              output_size) {
     # should we overlay a classified image?
     if (!purrr::is_null(class_cube)) {
@@ -604,19 +641,23 @@
         )
         # get the labels
         labels <- unlist(.cube_labels(class_cube, dissolve = FALSE))
-        if (purrr::is_null(names(labels)))
+        if (purrr::is_null(names(labels))) {
             names(labels) <- seq_along(labels)
+        }
         # obtain the colors
         colors <- .colors_get(
             labels = labels,
             legend = legend,
-            color_palette = color_palette,
+            palette = palette,
             rev = TRUE
         )
         # select the tiles that will be shown
-        if (!purrr::is_null(tiles))
-            class_cube <- dplyr::filter(class_cube,
-                                        .data[["tile"]] %in% tiles)
+        if (!purrr::is_null(tiles)) {
+            class_cube <- dplyr::filter(
+                class_cube,
+                .data[["tile"]] %in% tiles
+            )
+        }
 
         # create the stars objects that correspond to the tiles
         st_objs <- slider::slide(class_cube, function(tile) {
@@ -650,12 +691,13 @@
         leaf_map <- leaf_map |>
             leafem::addStarsImage(
                 x = st_obj_new,
+                opacity = opacity,
                 colors = colors,
                 method = "ngb",
                 group = "classification",
                 project = FALSE,
                 maxBytes = output_size["leaflet_maxbytes"]
-        )
+            )
     }
     return(leaf_map)
 }
@@ -663,8 +705,8 @@
                                   band_file,
                                   tile,
                                   band,
-                                  date = NULL,
-                                  color_palette,
+                                  date,
+                                  palette,
                                   output_size) {
     # create a stars object
     st_obj <- stars::read_stars(
@@ -681,16 +723,17 @@
         src = st_obj,
         crs = sf::st_crs("EPSG:3857")
     )
-    if (!purrr::is_null(date))
-        group <-  paste(tile[["tile"]], date)
-    else
-        group <-  paste(tile[["tile"]], band)
+    if (!purrr::is_null(date)) {
+        group <- paste(tile[["tile"]], date)
+    } else {
+        group <- paste(tile[["tile"]], band)
+    }
     # add stars to leaflet
     leaf_map <- leafem::addStarsImage(
         leaf_map,
         x = st_obj_new,
         band = 1,
-        colors = color_palette,
+        colors = palette,
         project = FALSE,
         group = group,
         maxBytes = output_size["leaflet_maxbytes"]
@@ -712,15 +755,9 @@
     # get the timeline
     timeline <- .cube_timeline(cube)[[1]]
 
-    if (purrr::is_null(dates))
+    if (purrr::is_null(dates)) {
         dates <- timeline[1]
-
-    # check dates exist
-    .check_that(
-        x = all(as.Date(dates) %in% timeline),
-        local_msg = "date is not in cube timeline",
-        msg = "invalid dates parameter"
-    )
+    }
     return(dates)
 }
 #' @title  Select the tiles to be visualised
@@ -743,13 +780,55 @@
     )
     # filter the tiles to be processed
     cube <- .cube_filter_tiles(cube, tiles)
-
-    # more than one tile? needs regular cube
-    if (nrow(cube) > 1)
-        .check_is_regular(cube)
-
     return(cube)
 }
+#' @title  Get the labels for a classified vector cube
+#' @name .view_get_labels_raster
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @param  class_cube    Classified raster cube
+#' @return               Labels
+#'
+#'
+.view_get_labels_raster <- function(class_cube){
+    labels <- unlist(.cube_labels(class_cube, dissolve = FALSE))
+    return(labels)
+}
+#' @title  Get the labels for a classified vector cube
+#' @name .view_get_labels_vector
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @param  cube          Classified vector cube
+#' @param  legend        Class legend
+#' @param  palette       Color palette
+#' @return               Leaflet map with legend
+#'
+#'
+.view_get_labels_vector <- function(cube,
+                                    legend = NULL,
+                                    palette = NULL) {
+    # get segments from cube
+    labels <- slider::slide(cube, function(tile){
+        # retrieve the segments for this tile
+        segments <- .segments_read_vec(tile)
+        # dissolve segments
+        segments <- segments |>
+            dplyr::group_by(.data[["class"]]) |>
+            dplyr::summarise()
+        # get the labels
+        labels_tile <- segments |>
+            sf::st_drop_geometry() |>
+            dplyr::select("class") |>
+            dplyr::pull()
+        return(labels_tile)
+    })
+    labels <- unique(unlist(labels))
+    return(labels)
+}
 #' @title  Add a legend to the leafmap
 #' @name .view_add_legend
 #' @keywords internal
@@ -757,51 +836,35 @@
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @param  leaf_map      Leaflet map
-#' @param  class_cube    Classified cube
-#' @param  segments      Segments
+#' @param  cube          Vector or raster cube
 #' @param  legend        Class legend
-#' @param  color_palette Color palette
+#' @param  palette       Color palette
 #' @return               Leaflet map with legend
 #'
 #'
 .view_add_legend <- function(leaf_map,
-                             class_cube = NULL,
-                             legend = NULL,
-                             segments = NULL,
-                             color_palette = NULL) {
-
+                             cube,
+                             legend,
+                             palette) {
     # initialize labels
     labels <- NULL
-    # if class_cube exists, get fact_pal
-    if (!purrr::is_null(class_cube)) {
-        # get the labels
-        labels <- unlist(.cube_labels(class_cube, dissolve = FALSE))
-    } else {
-        # get fact_pal from the segments
-        if (!purrr::is_null(segments)) {
-            # have the segments been classified?
-            sf_seg <- segments[[1]]
-            if ("class" %in% colnames(sf_seg)) {
-                # dissolve sf_seg
-                sf_seg <- sf_seg |>
-                    dplyr::group_by(.data[["class"]]) |>
-                    dplyr::summarise()
-                # get the labels
-                labels <- sf_seg |>
-                    sf::st_drop_geometry() |>
-                    dplyr::select("class") |>
-                    dplyr::pull()
-            }
+
+    # obtain labels from class cube
+    if (!purrr::is_null(cube)) {
+        if (inherits(cube, "class_cube")) {
+            labels <- .view_get_labels_raster(cube)
+        }
+        if (inherits(cube, "class_vector_cube")) {
+            labels <- .view_get_labels_vector(cube)
         }
     }
-    # are there any labels to the shown in the legend?
     if (!purrr::is_null(labels)) {
-        # obtain the colors
+        # obtain labels from vector class cube
         labels <- sort(unname(labels))
         colors <- .colors_get(
             labels = labels,
             legend = legend,
-            color_palette = color_palette,
+            palette = palette,
             rev = TRUE
         )
         # create a palette of colors
@@ -812,61 +875,92 @@
         leaf_map <- leaflet::addLegend(
             map = leaf_map,
             position = "topright",
-            pal     = fact_pal,
-            values  = labels,
-            title   = "Classes",
+            pal = fact_pal,
+            values = labels,
+            title = "Classes",
             opacity = 1
         )
     }
     return(leaf_map)
 }
-
 #' @title  Add overlay groups to leaflet map
-#' @name .view_add_overlay_grps
 #' @keywords internal
 #' @noRd
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @param  cube          Raster cube
+#' @param  dates         Dates
 #' @param  class_cube    Classified cube
-#' @param  segments      Segments
 #' @return               Leaflet map with with overlay groups
+.view_add_overlay_grps <- function(cube, ...,
+                                   dates = NULL,
+                                   class_cube = NULL) {
+    UseMethod(".view_add_overlay_grps", cube)
+}
 #'
-.view_add_overlay_grps <- function(
-        cube = NULL,
-        dates = NULL,
-        class_cube = NULL,
-        segments = NULL) {
-
+#' @export
+.view_add_overlay_grps.raster_cube <- function(cube, ...,
+                                               dates = NULL,
+                                               class_cube = NULL) {
     overlay_groups <- NULL
-
-    if (!purrr::is_null(cube)) {
-       if (!inherits(cube, "derived_cube")) {
-            # raster cube needs dates
-            .check_that(
-                x = !purrr::is_null(dates),
-                msg = "raster cube must have associated dates"
-            )
-            grps <- unlist(purrr::map(cube[["tile"]], function(tile) {
-                paste(tile, dates)
-            }))
-            overlay_groups <- c(overlay_groups, grps)
-       } else {
-           grps <- unlist(purrr::map(cube[["tile"]], function(tile) {
-               paste(tile, .cube_bands(cube))
-           }))
-           overlay_groups <- c(overlay_groups, grps)
-       }
-    }
+    # raster cube needs dates
+    .check_that(
+        x = !purrr::is_null(dates),
+        msg = "raster cube must have associated dates"
+    )
+    grps <- unlist(purrr::map(cube[["tile"]], function(tile) {
+        paste(tile, dates)
+    }))
+    overlay_groups <- c(overlay_groups, grps)
     # add class_cube
     if (!purrr::is_null(class_cube))
         overlay_groups <- c(overlay_groups, "classification")
-    # add segments
-    if (!purrr::is_null(segments))
-        overlay_groups <- c(overlay_groups, "segments")
-
     return(overlay_groups)
 }
+#'
+#' @export
+.view_add_overlay_grps.derived_cube <- function(cube, ...,
+                                                dates = NULL,
+                                                class_cube = NULL) {
+
+    overlay_groups <- NULL
+    grps <- unlist(purrr::map(cube[["tile"]], function(tile) {
+        paste(tile, .cube_bands(cube))
+    }))
+    overlay_groups <- c(overlay_groups, grps)
+    # add class_cube
+    if (!purrr::is_null(class_cube))
+        overlay_groups <- c(overlay_groups, "classification")
+    return(overlay_groups)
+}
+#'
+#' @export
+.view_add_overlay_grps.vector_cube <- function(cube, ...,
+                                               dates = NULL,
+                                               class_cube = NULL) {
+    overlay_groups <- NULL
+    if (!purrr::is_null(dates)) {
+        grps <- unlist(purrr::map(cube[["tile"]], function(tile) {
+            paste(tile, dates)
+        }))
+        overlay_groups <- c(overlay_groups, grps)
+    }
+    overlay_groups <- c(overlay_groups, "segments")
+    if ("class_vector_cube" %in% class(cube))
+        overlay_groups <- c(overlay_groups, "class_segments")
+    if (!purrr::is_null(class_cube))
+        overlay_groups <- c(overlay_groups, "classification")
+    return(overlay_groups)
+}
+#' @title  Add base maps to leaflet map
+#' @name .view_get_base_maps
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @param  leaf_map      Leaflet
+#' @return               Base maps used in leaflet map
+#'
 .view_get_base_maps <- function(leaf_map) {
     base_maps <- purrr::map_chr(leaf_map$x$calls, function(c) {
         return(c$args[[3]])
