@@ -1,12 +1,24 @@
 #' @title Filter time series with smoothing filter
 #' @name sits_filter
-#' @param data          Time series or matrix.
+#' @param data          Time series (tibble of class "sits") or matrix.
 #' @param filter        Filter function to be applied.
+#' @return              Filtered time series
 #'
 #' @description
 #'  Applies a filter to all bands, using a filter function
-#'  such as `sits_whittaker()` or `sits_sgolay()`.
-#'
+#'  such as sits_whittaker() or sits_sgolay().
+#' @examples
+#' if (sits_run_examples()) {
+#'     # Retrieve a time series with values of NDVI
+#'     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
+#'     # Filter the point using the Whittaker smoother
+#'     point_whit <- sits_filter(point_ndvi, sits_whittaker(lambda = 3.0))
+#'     # Merge time series
+#'     point_ndvi <- sits_merge(point_ndvi, point_whit,
+#'                              suffix = c("", ".WHIT"))
+#'     # Plot the two points to see the smoothing effect
+#'     plot(point_ndvi)
+#' }
 #' @export
 sits_filter <- function(data, filter = sits_whittaker()) {
     result <- filter(data)
@@ -40,16 +52,15 @@ sits_filter <- function(data, filter = sits_whittaker()) {
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#' # Retrieve a time series with values of NDVI
-#' point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
-#'
-#' # Filter the point using the Whittaker smoother
-#' point_whit <- sits_filter(point_ndvi, sits_whittaker(lambda = 3.0))
-#' # Merge time series
-#' point_ndvi <- sits_merge(point_ndvi, point_whit, suffix = c("", ".WHIT"))
-#'
-#' # Plot the two points to see the smoothing effect
-#' plot(point_ndvi)
+#'     # Retrieve a time series with values of NDVI
+#'     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
+#'     # Filter the point using the Whittaker smoother
+#'     point_whit <- sits_filter(point_ndvi, sits_whittaker(lambda = 3.0))
+#'     # Merge time series
+#'     point_ndvi <- sits_merge(point_ndvi, point_whit,
+#'                             suffix = c("", ".WHIT"))
+#'     # Plot the two points to see the smoothing effect
+#'     plot(point_ndvi)
 #' }
 #' @export
 sits_whittaker <- function(data = NULL, lambda = 0.5) {
@@ -98,18 +109,18 @@ sits_whittaker <- function(data = NULL, lambda = 0.5) {
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#' # Retrieve a time series with values of NDVI
-#' point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
+#'     # Retrieve a time series with values of NDVI
+#'     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
 #'
-#' # Filter the point using the Savitzky-Golay smoother
-#' point_sg <- sits_filter(point_ndvi,
-#'     filter = sits_sgolay(order = 3, length = 5)
-#' )
-#' # Merge time series
-#' point_ndvi <- sits_merge(point_ndvi, point_sg, suffix = c("", ".SG"))
+#'     # Filter the point using the Savitzky-Golay smoother
+#'     point_sg <- sits_filter(point_ndvi,
+#'         filter = sits_sgolay(order = 3, length = 5)
+#'     )
+#'     # Merge time series
+#'     point_ndvi <- sits_merge(point_ndvi, point_sg, suffix = c("", ".SG"))
 #'
-#' # Plot the two points to see the smoothing effect
-#' plot(point_ndvi)
+#'     # Plot the two points to see the smoothing effect
+#'     plot(point_ndvi)
 #' }
 #' @export
 sits_sgolay <- function(data = NULL, order = 3, length = 5) {
@@ -123,15 +134,15 @@ sits_sgolay <- function(data = NULL, order = 3, length = 5) {
                 data,
                 f_res = f_res,
                 p = order,
-                n = length)
-            )
+                n = length
+            ))
         } else {
             return(smooth_sg(
                 data,
                 f_res = f_res,
                 p = order,
-                n = length)
-            )
+                n = length
+            ))
         }
     }
 
