@@ -30,10 +30,6 @@
 #' Active learning and annotation for human-centered AI. Simon and Schuster,
 #' 2021.
 #'
-#' @note
-#' Please refer to the sits documentation available in
-#' <https://e-sensing.github.io/sitsbook/> for detailed examples.
-#'
 #' @examples
 #' if (sits_run_examples()) {
 #'     # create a random forest model
@@ -55,24 +51,26 @@
 #'     plot(uncert_cube)
 #' }
 #' @export
-sits_uncertainty <- function(cube,
-                             type = "entropy",
-                             multicores = 2,
-                             memsize = 4,
-                             output_dir,
-                             version = "v1") {
-
+sits_uncertainty <- function(
+        cube,
+        type = "entropy",
+        multicores = 2,
+        memsize = 4,
+        output_dir,
+        version = "v1") {
     # Check if cube has probability data
-    .check_is_probs_cube(cube)
+    .check_cube_files(cube)
+    .check_cube_is_probs_cube(cube)
     # Check memsize
-    .check_memsize(memsize)
+    .check_memsize(memsize, min = 1, max = 16384)
     # Check multicores
-    .check_multicores(multicores)
+    .check_multicores(multicores, min = 1, max = 2048)
     # check output dir
     .check_output_dir(output_dir)
     # check version
-    .check_version(version)
-
+    version <- .check_version(version)
+    # version is case-insensitive in sits
+    version <- tolower(version)
     # Check memory and multicores
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(cube)))
@@ -81,7 +79,7 @@ sits_uncertainty <- function(cube,
         job_size = .block_size(block = block, overlap = 0),
         npaths = length(.tile_labels(cube)) + 1,
         nbytes = 8,
-        proc_bloat = .conf("processing_bloat")
+        proc_bloat = .conf("processing_bloat_cpu")
     )
     # Update multicores parameter
     multicores <- .jobs_max_multicores(
@@ -89,11 +87,9 @@ sits_uncertainty <- function(cube,
         memsize = memsize,
         multicores = multicores
     )
-
     # Prepare parallel processing
     .parallel_start(workers = multicores)
     on.exit(.parallel_stop(), add = TRUE)
-
     # Define the class of the smoothing
     class(type) <- c(type, class(type))
     UseMethod("sits_uncertainty", type)
@@ -101,15 +97,15 @@ sits_uncertainty <- function(cube,
 
 #' @rdname sits_uncertainty
 #' @export
-sits_uncertainty.least <- function(cube,
-                                   type = "least",
-                                   multicores = 2,
-                                   memsize = 4,
-                                   output_dir,
-                                   version = "v1") {
-
+sits_uncertainty.least <- function(
+        cube,
+        type = "least",
+        multicores = 2,
+        memsize = 4,
+        output_dir,
+        version = "v1") {
     # Compute uncertainty
-    uncert_cube <- .cube_uncertainty(
+    uncert_cube <- .uncertainty_cube(
         cube = cube,
         band = "least",
         uncert_fn = .uncertainty_fn_least(),
@@ -118,17 +114,17 @@ sits_uncertainty.least <- function(cube,
     )
     return(uncert_cube)
 }
-
 #' @rdname sits_uncertainty
 #' @export
-sits_uncertainty.entropy <- function(cube,
-                                     type = "entropy",
-                                     multicores = 2,
-                                     memsize = 4,
-                                     output_dir,
-                                     version = "v1") {
+sits_uncertainty.entropy <- function(
+        cube,
+        type = "entropy",
+        multicores = 2,
+        memsize = 4,
+        output_dir,
+        version = "v1") {
     # Compute uncertainty
-    uncert_cube <- .cube_uncertainty(
+    uncert_cube <- .uncertainty_cube(
         cube = cube,
         band = "entropy",
         uncert_fn = .uncertainty_fn_entropy(),
@@ -140,14 +136,15 @@ sits_uncertainty.entropy <- function(cube,
 
 #' @rdname sits_uncertainty
 #' @export
-sits_uncertainty.margin <- function(cube,
-                                    type = "margin",
-                                    multicores = 2,
-                                    memsize = 4,
-                                    output_dir,
-                                    version = "v1") {
+sits_uncertainty.margin <- function(
+        cube,
+        type = "margin",
+        multicores = 2,
+        memsize = 4,
+        output_dir,
+        version = "v1") {
     # Create uncertainty cube
-    uncert_cube <- .cube_uncertainty(
+    uncert_cube <- .uncertainty_cube(
         cube = cube,
         band = "margin",
         uncert_fn = .uncertainty_fn_margin(),
@@ -156,4 +153,14 @@ sits_uncertainty.margin <- function(cube,
     )
     return(uncert_cube)
 }
-
+#' @rdname sits_uncertainty
+#' @export
+sits_uncertainty.default <- function(
+        cube,
+        type,
+        multicores,
+        memsize,
+        output_dir,
+        version) {
+    stop("Invalid type of method for uncertainty estimation")
+}
