@@ -19,10 +19,12 @@ test_that("Downloading and cropping cubes from BDC", {
         purrr::is_null(cbers_cube),
         "BDC is not accessible"
     )
-    roi_xy <- c(xmin = 5800000,
-                xmax = 5900000,
-                ymin = 9600000,
-                ymax = 9700000)
+    roi_xy <- c(
+        xmin = 5800000,
+        xmax = 5900000,
+        ymin = 9600000,
+        ymax = 9700000
+    )
 
     cube_local_roi <- sits_cube_copy(
         cube = cbers_cube,
@@ -31,7 +33,16 @@ test_that("Downloading and cropping cubes from BDC", {
         multicores = 1,
         progress = FALSE
     )
-
+    msg <- capture_messages(
+        sits_cube_copy(
+            cube = cbers_cube,
+            output_dir = tempdir(),
+            roi = roi_xy,
+            multicores = 1,
+            progress = FALSE
+        )
+    )
+    expect_true(grepl("Recovery", msg[1]))
     # Comparing tiles
     expect_true(nrow(cbers_cube) >= nrow(cube_local_roi))
     bbox_tile <- sits_bbox(cbers_cube)
@@ -46,17 +57,22 @@ test_that("Downloading and cropping cubes from BDC", {
     # Comparing timelines
     expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi))
     # Comparing X resolution
-    expect_equal(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
-                 cube_local_roi[["file_info"]][[1]][["xres"]][[1]])
+    expect_equal(
+        cbers_cube[["file_info"]][[1]][["xres"]][[1]],
+        cube_local_roi[["file_info"]][[1]][["xres"]][[1]]
+    )
     # Comparing Y resolution
-    expect_equal(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
-                 cube_local_roi[["file_info"]][[1]][["yres"]][[1]])
+    expect_equal(
+        cbers_cube[["file_info"]][[1]][["yres"]][[1]],
+        cube_local_roi[["file_info"]][[1]][["yres"]][[1]]
+    )
     files <- cube_local_roi$file_info[[1]]$path
     unlink(files)
 
     roi_ll <- .roi_as_sf(roi_xy,
-                         default_crs = cbers_cube$crs[[1]],
-                         as_crs = 4326)
+        default_crs = cbers_cube$crs[[1]],
+        as_crs = 4326
+    )
 
     cube_local_roi_ll <- sits_cube_copy(
         cube = cbers_cube,
@@ -79,11 +95,15 @@ test_that("Downloading and cropping cubes from BDC", {
     # Comparing timelines
     expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi_ll))
     # Comparing X resolution
-    expect_equal(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
-                 cube_local_roi_ll[["file_info"]][[1]][["xres"]][[1]])
+    expect_equal(
+        cbers_cube[["file_info"]][[1]][["xres"]][[1]],
+        cube_local_roi_ll[["file_info"]][[1]][["xres"]][[1]]
+    )
     # Comparing Y resolution
-    expect_equal(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
-                 cube_local_roi_ll[["file_info"]][[1]][["yres"]][[1]])
+    expect_equal(
+        cbers_cube[["file_info"]][[1]][["yres"]][[1]],
+        cube_local_roi_ll[["file_info"]][[1]][["yres"]][[1]]
+    )
     files <- cube_local_roi_ll$file_info[[1]]$path
     unlink(files)
 
@@ -118,11 +138,15 @@ test_that("Downloading and cropping cubes from BDC", {
     # Comparing timelines
     expect_equal(sits_timeline(cbers_cube), sits_timeline(cube_local_roi_tr))
     # Comparing X resolution
-    expect_lt(cbers_cube[["file_info"]][[1]][["xres"]][[1]],
-              cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]])
+    expect_lt(
+        cbers_cube[["file_info"]][[1]][["xres"]][[1]],
+        cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]]
+    )
     # Comparing Y resolution
-    expect_lt(cbers_cube[["file_info"]][[1]][["yres"]][[1]],
-              cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]])
+    expect_lt(
+        cbers_cube[["file_info"]][[1]][["yres"]][[1]],
+        cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]]
+    )
     files <- cube_local_roi_tr$file_info[[1]]$path
     unlink(files)
 })
@@ -131,11 +155,11 @@ test_that("Downloading entire images from local cubes", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 
     cube <- sits_cube(
-                source = "BDC",
-                collection = "MOD13Q1-6",
-                data_dir = data_dir,
-                multicores = 2,
-                progress = FALSE
+        source = "BDC",
+        collection = "MOD13Q1-6",
+        data_dir = data_dir,
+        multicores = 2,
+        progress = FALSE
     )
 
     cube_local <- sits_cube_copy(
@@ -158,21 +182,27 @@ test_that("Downloading entire images from local cubes", {
     # Comparing timelines
     expect_equal(sits_timeline(cube), sits_timeline(cube_local))
     # Comparing X resolution
-    expect_equal(cube[["file_info"]][[1]][["xres"]][[1]],
-                 cube_local[["file_info"]][[1]][["xres"]][[1]])
+    expect_equal(
+        cube[["file_info"]][[1]][["xres"]][[1]],
+        cube_local[["file_info"]][[1]][["xres"]][[1]]
+    )
     # Comparing Y resolution
-    expect_equal(cube[["file_info"]][[1]][["yres"]][[1]],
-                 cube_local[["file_info"]][[1]][["yres"]][[1]])
+    expect_equal(
+        cube[["file_info"]][[1]][["yres"]][[1]],
+        cube_local[["file_info"]][[1]][["yres"]][[1]]
+    )
     files <- cube_local$file_info[[1]]$path
     unlink(files)
 
     cube_local_roi_tr <- sits_cube_copy(
         cube = cube,
         output_dir = tempdir(),
-        roi = c(lon_min = -55.62248575,
-                lat_min = -11.62017052,
-                lon_max = -55.60154307,
-                lat_max = -11.60790603),
+        roi = c(
+            lon_min = -55.62248575,
+            lat_min = -11.62017052,
+            lon_max = -55.60154307,
+            lat_max = -11.60790603
+        ),
         res = 464,
         multicores = 2,
         progress = FALSE
@@ -189,11 +219,15 @@ test_that("Downloading entire images from local cubes", {
     # Comparing timelines
     expect_equal(sits_timeline(cube), sits_timeline(cube_local_roi_tr))
     # Comparing X resolution
-    expect_lt(cube[["file_info"]][[1]][["xres"]][[1]],
-              cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]])
+    expect_lt(
+        cube[["file_info"]][[1]][["xres"]][[1]],
+        cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]]
+    )
     # Comparing Y resolution
-    expect_lt(cube[["file_info"]][[1]][["yres"]][[1]],
-              cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]])
+    expect_lt(
+        cube[["file_info"]][[1]][["yres"]][[1]],
+        cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]]
+    )
     expect_equal(cube_local_roi_tr[["file_info"]][[1]][["xres"]][[1]], 464)
     expect_equal(cube_local_roi_tr[["file_info"]][[1]][["yres"]][[1]], 464)
     files <- cube_local_roi_tr$file_info[[1]]$path
