@@ -5,8 +5,10 @@ test_that("One-year, multicores processing reclassify", {
         source = "USGS",
         collection = "LANDSAT-C2L2-SR",
         data_dir = data_dir,
-        parse_info = c("X1", "X2", "tile", "start_date", "end_date",
-                       "band", "version"),
+        parse_info = c(
+            "X1", "X2", "tile", "start_date", "end_date",
+            "band", "version"
+        ),
         bands = "class",
         version = "v20220606",
         labels = c("1" = "Forest", "2" = "Water", "3" = "NonForest",
@@ -28,11 +30,15 @@ test_that("One-year, multicores processing reclassify", {
         source = "MPC",
         collection = "SENTINEL-2-L2A",
         data_dir = data_dir,
-        parse_info = c("X1", "X2", "tile", "start_date", "end_date",
-                       "band", "version"),
+        parse_info = c(
+            "X1", "X2", "tile", "start_date", "end_date",
+            "band", "version"
+        ),
         bands = "class",
-        labels = c("1" = "ClearCut_Fire", "2" = "ClearCut_Soil",
-                   "3" = "ClearCut_Veg", "4" = "Forest"),
+        labels = c(
+            "1" = "ClearCut_Fire", "2" = "ClearCut_Soil",
+            "3" = "ClearCut_Veg", "4" = "Forest"
+        ),
         progress = FALSE
     )
     # Reclassify cube
@@ -56,14 +62,17 @@ test_that("One-year, multicores processing reclassify", {
         ),
         memsize = 4,
         multicores = 2,
-        output_dir = tempdir()
+        output_dir = tempdir(),
+        version = "reclass"
     )
 
     expect_equal(
         sits_labels(ro_mask),
-        c("ClearCut_Fire", "ClearCut_Soil",
-          "ClearCut_Veg", "Forest", "Old_Deforestation",
-          "Water_Mask", "NonForest_Mask")
+        c(
+            "1" = "ClearCut_Fire", "2" =  "ClearCut_Soil",
+            "3" =  "ClearCut_Veg", "4" = "Forest",
+            "5" = "Old_Deforestation", "7" = "NonForest_Mask"
+        )
     )
     ro_class_obj <- .raster_open_rast(.tile_path(ro_class))
     prodes2021_obj <- .raster_open_rast(.tile_path(prodes2021))
@@ -76,7 +85,7 @@ test_that("One-year, multicores processing reclassify", {
     # ro_class is "ClearCut_Veg"
     expect_equal(vls_ro_class[2000], 3)
     # prodes2021 is ""d2018"
-    expect_equal(vls_prodes2021[2000], 17)
+    expect_equal(vls_prodes2021[2000], 1)
     # ro_class is "Old_Deforestation"
     expect_equal(vls_ro_mask[2000], 5)
 
@@ -104,12 +113,81 @@ test_that("One-year, multicores processing reclassify", {
                     ),
                     memsize = 4,
                     multicores = 2,
-                    output_dir = tempdir()
-                )},
+                    output_dir = tempdir(),
+                    version = "reclass"
+                )
+            },
             regexp = "Recovery: "
         )
     })
+
     expect_true(grepl("output_dir", out[1]))
 
     unlink(ro_mask$file_info[[1]]$path)
 })
+
+test_that("One-year, reclassify different rules", {
+    rf_model <- sits_train(samples_modis_ndvi, ml_method = sits_rfor)
+
+    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
+
+    cube <- sits_cube(
+        source = "BDC",
+        collection = "MOD13Q1-6",
+        data_dir = data_dir
+    )
+
+    probs_cube <- sits_classify(
+        data = cube,
+        ml_model = rf_model,
+        output_dir = tempdir(),
+        version = "ex_classify",
+        multicores = 2,
+        memsize = 4
+    )
+
+    label_cube <- sits_label_classification(
+        probs_cube,
+        output_dir = tempdir(),
+        multicores = 2,
+        memsize = 4
+    )
+
+    reclass <- sits_reclassify(
+        cube = label_cube,
+        mask = label_cube,
+        rules = list(
+            Cerrado = mask %in% c("Pasture", "Cerrado")
+        ),
+        output_dir = tempdir(),
+        multicores = 2,
+        memsize = 4
+    )
+
+    expect_equal(
+        object = sits_labels(reclass),
+        expected = c("1" =  "Cerrado", "2" = "Forest", "4" = "Soy_Corn")
+    )
+
+    reclassv2 <- sits_reclassify(
+        cube = label_cube,
+        mask = label_cube,
+        rules = list(
+            CerradoNew = mask %in% c("Pasture", "Cerrado")
+        ),
+        output_dir = tempdir(),
+        version = "v2",
+        multicores = 2,
+        memsize = 4
+    )
+
+    expect_equal(
+        object = sits_labels(reclassv2),
+        expected = c("2" = "Forest", "4" = "Soy_Corn", "5" = "CerradoNew")
+    )
+
+    unlink(reclassv2$file_info[[1]]$path)
+    unlink(reclass$file_info[[1]]$path)
+    unlink(label_cube$file_info[[1]]$path)
+    unlink(probs_cube$file_info[[1]]$path)
+})
